XmlValue

Enum XmlValue 

pub enum XmlValue {
    String(String),
    Integer(i64),
    Float(f64),
    Boolean(bool),
    Null,
    Array(XmlArray),
    Object(XmlObject),
}
XML value representation.

This represents the pure value of an XML element without any source code location information.

Variants



String(String)

String value.



Integer(i64)

Integer value.



Float(f64)

Floating-point value.



Boolean(bool)

Boolean value.



Null

Null value.



Array(XmlArray)

Array value.



Object(XmlObject)

Object value.

Implementations

Source

impl XmlValue

pub fn as_str(&self) -> Option<&str>

Returns the string slice if the value is a string.

pub fn as_integer(&self) -> Option<i64>

Returns the integer value if the value is an integer.

pub fn as_float(&self) -> Option<f64>

Returns the floating-point value if the value is a float.

pub fn as_bool(&self) -> Option<bool>

Returns the boolean value if the value is a boolean.

pub fn is_null(&self) -> bool

Returns true if the value is null.

pub fn as_array(&self) -> Option<&Vec<XmlValue>>

Returns a reference to the array if the value is an array.

pub fn as_object(&self) -> Option<&HashMap<String, XmlValue>>

Returns a reference to the object if the value is an object.

pub fn get(&self, key: &str) -> Option<&XmlValue>

Gets a value from the object by key name.