XmlNode

Type Alias XmlNode 

pub type XmlNode<'a> = RedNode<'a, XmlLanguage>;
A node in the XML red tree.

Aliased Type

pub struct XmlNode<'a> {
    pub green: &'a GreenNode<'a, XmlLanguage>,
    pub offset: usize,
}

Fields

green: &'a GreenNode<'a, XmlLanguage>

The underlying green node that contains the structural information.

offset: usize

The absolute byte offset of this node in the source text.